@@ -5,7 +5,6 @@ from prophet.diagnostics import performance_metrics
 from prophet.utilities import regressor_coefficients
 
 from tabulate import tabulate
-from sklearn.metrics import r2_score, mean_absolute_error
 
 import pandas as pd
 from pandas import DataFrame
@@ -14,8 +13,6 @@ import numpy as np
 
 import itertools
 
-import logging
-
 from tscausalinference.evaluators import mape
 
 def prophet_regression(df: DataFrame = pd.DataFrame(), 
@@ -24,7 +21,9 @@ def prophet_regression(df: DataFrame = pd.DataFrame(),
                          alpha: float = 0.05, 
                          model_params: dict = {}, 
                          regressors: list = [],
-                         verbose = True):
+                         verbose = True,
+                         model_type = 'gam',
+                         autocorrelation = False):
 
     if not isinstance(df, pd.DataFrame):
         raise ValueError("df must be a pandas DataFrame")
@@ -46,14 +45,20 @@ def prophet_regression(df: DataFrame = pd.DataFrame(),
                 'holidays': None,
                 'seasonality_mode': 'additive',
                 'changepoint_prior_scale': 0.05,
-                'mcmc_samples': 1000,
                 'interval_width': 1 - alpha}
         
         print('Default parameters grid: \n{}',format(model_parameters))
     else:
         model_parameters = model_params.copy()
     
-    pre_intervention = [df.ds.min(),(pd.to_datetime(intervention[0]) - pd.Timedelta(days=1)).strftime('%Y-%m-%d')]
+    df['y_lag7'] = df.y.shift(7)
+    df['y_lag14'] = df.y.shift(14)
+    
+    if autocorrelation:
+        regressors.append('y_lag7')
+        regressors.append('y_lag14')
+    
+    pre_intervention = [df.ds.min(), (pd.to_datetime(intervention[0]) - pd.Timedelta(days=1)).strftime('%Y-%m-%d')]
     post_intervention = [(pd.to_datetime(intervention[1]) + pd.Timedelta(days=1)).strftime('%Y-%m-%d'), df.ds.max()]
 
     training_dataframe = df[(df.ds >= pd.to_datetime(pre_intervention[0]))&(df.ds <= pd.to_datetime(pre_intervention[1]))&(df.y > 0)].fillna(0).copy()
@@ -66,6 +71,7 @@ def prophet_regression(df: DataFrame = pd.DataFrame(),
 
     print('Training period: {} to {}'.format(pre_intervention[0], pre_intervention[1]))
     print('Test period: {} to {}\n'.format(intervention[0], intervention[1]))
+    print('Post period: {} to {}\n'.format(post_intervention[0], post_intervention[1]))
     print('Prediction horizon: {} days'.format(prediction_period))
     
     condition_int = isinstance(model_parameters[list(model_parameters.keys())[0]], float)
@@ -94,14 +100,20 @@ def prophet_regression(df: DataFrame = pd.DataFrame(),
             best_params = all_params[np.argmin(rmses)]
             print(best_params)
             
-            prophet = Prophet(**best_params)
+            model_parameters = best_params.copy()
+            prophet = Prophet(**model_parameters)
         else:
             raise TypeError("Your parameters on the Grid are not list type")
     
     else:
         model_parameters.update({'interval_width': 1 - alpha})
-        print('Custom parameters grid: \n{}',format(model_parameters))
-        prophet = Prophet(**model_parameters)
+        print('Custom parameters grid: \n{}'.format(model_parameters))
+        if model_type == 'bayesian':
+            model_parameters.update({'mcmc_samples': 1000})
+            prophet = Prophet(**model_parameters)
+            
+        else:
+            prophet = Prophet(**model_parameters)
 
     for regressor in regressors:
             prophet.add_regressor(name = regressor)
@@ -139,4 +151,4 @@ def prophet_regression(df: DataFrame = pd.DataFrame(),
         if verbose:
             print(tabulate(table, headers=['Regressor', 'Regressor Mode', 'Center', 'Coef. Lower', 'Coef', 'Coef. Upper'], tablefmt='grid'))    
 
-    return data
+    return data, model_parameters
