@@ -109,9 +109,7 @@ def summary_intervention(data, intervention = None, int_metrics = None):
     --------
         No returns are defined, as the method simply generates a overview.
     """
-    data = data.copy()
-    lower = data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].yhat_lower.sum()
-    upper = data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].yhat_upper.sum()
+    data = data
 
     strings_info = """
 +-----------------------+------------+
@@ -128,8 +126,7 @@ def summary_intervention(data, intervention = None, int_metrics = None):
             headers=['Metric', 'Value'], 
             tablefmt='pipe'),
             'CI 95%: [{}, {}]'.format(
-                round(lower, 0), 
-                round(upper, 0)
-            )
+                round(data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].yhat_lower.sum(),2), 
+                round(data[(data.ds >= intervention[0]) & (data.ds <= intervention[1])].yhat_upper.sum()),2)
         ).strip()
     )
\ No newline at end of file
